<?php
/* ======================================================
 # Support Hours for Joomla! - v1.6.2 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v4.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://demo.web357.com/joomla/browse/support-hours
 # Support: support@web357.com
 # Last modified: Monday 10 July 2023, 03:51:28 AM
 ========================================================= */
defined('JPATH_BASE') or die;

jimport('joomla.form.formfield');
jimport( 'joomla.form.form' );

class JFormFielddateformat extends JFormField {
	
	protected $type = 'dateformat';

	protected function getLabel()
	{
		return '<label id="jform_params_dateformat-lbl" for="jform_params_dateformat" class="hasTooltip" title="&lt;strong&gt;'.JText::_('MOD_SUPPORTHOURS_DATEFORMAT_LBL').'&lt;/strong&gt;&lt;br /&gt;'.JText::_('MOD_SUPPORTHOURS_DATEFORMAT_DESC').'">'.JText::_('MOD_SUPPORTHOURS_DATEFORMAT_LBL').'</label>';	
	}

	protected function getInput() 
	{
		/*
		yy – Two-digit year, e.g. 96
		yyyy – Four-digit year, e.g. 1996
		m – One-digit month for months below 10, e.g. 4
		mm – Two-digit month, e.g. 04
		mmm – Three-letter abbreviation for month, e.g. Apr
		mmmm – Month spelled out in full, e.g. April
		d – One-digit day for days below 10, e.g. 2
		dd – Two-digit day, e.g. 02
		*/

		// Full Date Format
		$date_formats_arr_a = array();
		$date_formats_arr_a["dddd, d mmmm yyyyy"] = "dddd, d mmmm yyyyy";
		$date_formats_arr_a["dddd, dd mmmm yyyyy"] = "dddd, dd mmmm yyyyy";
		$date_formats_arr_a["dddd, d mmm yyyyy"] = "dddd, d mmm yyyyy";
		$date_formats_arr_a["dddd, dd mmm yyyyy"] = "dddd, dd mmm yyyyy";
		$date_formats_arr_a["dddd, dd-mm-yyyyy"] = "dddd, dd-mm-yyyyy";

		// Month Day, Year
		$date_formats_arr_b = array();
		$date_formats_arr_b["mmmm dd, yyyy"] = "mmmm dd, yyyy";
		$date_formats_arr_b["mmmm d, yyyy"] = "mmmm d, yyyy";
		$date_formats_arr_b["mmm dd, yyyy"] = "mmm dd, yyyy";
		$date_formats_arr_b["mmm d, yyyy"] = "mmm d, yyyy";
		
		// Day Month, Year
		$date_formats_arr_c = array();
		$date_formats_arr_c["dd mmmm, yyyy"] = "dd mmmm, yyyy";
		$date_formats_arr_c["d mmmm, yyyy"] = "d mmmm, yyyy";
		$date_formats_arr_c["dd mmm, yyyy"] = "dd mmm, yyyy";
		$date_formats_arr_c["d mmm, yyyy"] = "d mmm, yyyy";
		
		// Day-Month-Year
		$date_formats_arr_d = array();
		$date_formats_arr_d["d-m-Y"] = "dd-mm-yyyy";
		$date_formats_arr_d["j-n-Y"] = "d-m-yyyy";
		
		// Month-Day-Year
		$date_formats_arr_e = array();
		$date_formats_arr_e["m-d-Y"] = "mm-dd-yyyy";
		$date_formats_arr_e["n-j-Y"] = "m-d-yyyy";
		
		// Year-Month-Day
		$date_formats_arr_f = array();
		$date_formats_arr_f["Y-m-d"] = "yyyy-mm-dd";
		$date_formats_arr_f["Y-n-j"] = "yyyy-m-d";
		
		// BEGIN: DEBUGGER
		/*$default_date = date("Y-m-d");
		$items_arr = array_merge($date_formats_arr_a, $date_formats_arr_b, $date_formats_arr_c, $date_formats_arr_d, $date_formats_arr_e, $date_formats_arr_f);
		foreach ($items_arr as $k=>$v):
			echo date($k, strtotime($default_date)).' ('.$v.')<br>';
		endforeach;*/
		// END: DEBUGGER

		// print
		$html = '';
		$html .= '<select id="'.$this->id.'" name="'.$this->name.'">';
		$html .= '<option value="">'.JText::_('MOD_SUPPORTHOURS_CHOOSE_DATE_FORMAT_VALUE').'</option>';

		// Full Date Format
		$html .= '<optgroup label="Full Date Format">';
		foreach ($date_formats_arr_a as $k=>$v):
			$html .= '<option value="'.$k.'"'.(($this->value == $k) ? ' selected="selected"' : '').'>'.$v.'</option>';
		endforeach;
		$html .= '</optgroup>';
		
		// Month Day, Year
		$html .= '<optgroup label="Month Day, Year">';
		foreach ($date_formats_arr_b as $k=>$v):
			$html .= '<option value="'.$k.'"'.(($this->value == $k) ? ' selected="selected"' : '').'>'.$v.'</option>';
		endforeach;
		$html .= '</optgroup>';
	
		// Day Month, Year
		$html .= '<optgroup label="Day Month, Year">';
		foreach ($date_formats_arr_c as $k=>$v):
			$html .= '<option value="'.$k.'"'.(($this->value == $k) ? ' selected="selected"' : '').'>'.$v.'</option>';
		endforeach;
		$html .= '</optgroup>';

		// Day-Month-Year
		$html .= '<optgroup label="Day-Month-Year">';
		foreach ($date_formats_arr_d as $k=>$v):
			$html .= '<option value="'.$k.'"'.(($this->value == $k) ? ' selected="selected"' : '').'>'.$v.'</option>';
		endforeach;
		$html .= '</optgroup>';

		// Month-Day-Year
		$html .= '<optgroup label="Month-Day-Year">';
		foreach ($date_formats_arr_e as $k=>$v):
			$html .= '<option value="'.$k.'"'.(($this->value == $k) ? ' selected="selected"' : '').'>'.$v.'</option>';
		endforeach;
		$html .= '</optgroup>';

		// Year-Month-Day
		$html .= '<optgroup label="Year-Month-Day">';
		foreach ($date_formats_arr_f as $k=>$v):
			$html .= '<option value="'.$k.'"'.(($this->value == $k) ? ' selected="selected"' : '').'>'.$v.'</option>';
		endforeach;
		$html .= '</optgroup>';

		$html .= '</select> ';
		
		// begin: info screenshot for parameter explanation
		$screenshot_src = $this->element["screenshot_src"];
		$screenshot_width = $this->element["screenshot_width"];
		$screenshot_height = $this->element["screenshot_height"];
		if (!empty($screenshot_src)):
			$screenshot_url = str_replace('/administrator', '', JURI::base()).$screenshot_src;
			$html .= '<a href="'.$screenshot_url.'" class="hasTooltip modal" data-original-title="Click to see an example." rel="{size: {x: '.$screenshot_width.', y: '.$screenshot_height.'}, handler:\'iframe\'}"><i style="margin-left: 10px;" class="icon-eye-open"></i></a>';
		endif;
		// end: info screenshot for parameter explanation
		
		return $html;
	}
	
}